==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1ContainerStateFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1ContainerStateFluentImpl<A extends V1ContainerStateFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ContainerStateFluent<A>{

    private V1ContainerStateRunningBuilder running;
    private V1ContainerStateTerminatedBuilder terminated;
    private V1ContainerStateWaitingBuilder waiting;

    public V1ContainerStateFluentImpl(){
    }
    public V1ContainerStateFluentImpl(V1ContainerState instance){
            this.withRunning(instance.getRunning());

            this.withTerminated(instance.getTerminated());

            this.withWaiting(instance.getWaiting());

    }

    
/**
 * This method has been deprecated, please use method buildRunning instead.
 * @return The buildable object.
 */
@Deprecated public V1ContainerStateRunning getRunning(){
            return this.running!=null?this.running.build():null;
    }

    public V1ContainerStateRunning buildRunning(){
            return this.running!=null?this.running.build():null;
    }

    public A withRunning(V1ContainerStateRunning running){
            _visitables.remove(this.running);
            if (running!=null){ this.running= new V1ContainerStateRunningBuilder(running); _visitables.add(this.running);} return (A) this;
    }

    public Boolean hasRunning(){
            return this.running != null;
    }

    public V1ContainerStateFluent.RunningNested<A> withNewRunning(){
            return new RunningNestedImpl();
    }

    public V1ContainerStateFluent.RunningNested<A> withNewRunningLike(V1ContainerStateRunning item){
            return new RunningNestedImpl(item);
    }

    public V1ContainerStateFluent.RunningNested<A> editRunning(){
            return withNewRunningLike(getRunning());
    }

    public V1ContainerStateFluent.RunningNested<A> editOrNewRunning(){
            return withNewRunningLike(getRunning() != null ? getRunning(): new V1ContainerStateRunningBuilder().build());
    }

    public V1ContainerStateFluent.RunningNested<A> editOrNewRunningLike(V1ContainerStateRunning item){
            return withNewRunningLike(getRunning() != null ? getRunning(): item);
    }

    
/**
 * This method has been deprecated, please use method buildTerminated instead.
 * @return The buildable object.
 */
@Deprecated public V1ContainerStateTerminated getTerminated(){
            return this.terminated!=null?this.terminated.build():null;
    }

    public V1ContainerStateTerminated buildTerminated(){
            return this.terminated!=null?this.terminated.build():null;
    }

    public A withTerminated(V1ContainerStateTerminated terminated){
            _visitables.remove(this.terminated);
            if (terminated!=null){ this.terminated= new V1ContainerStateTerminatedBuilder(terminated); _visitables.add(this.terminated);} return (A) this;
    }

    public Boolean hasTerminated(){
            return this.terminated != null;
    }

    public V1ContainerStateFluent.TerminatedNested<A> withNewTerminated(){
            return new TerminatedNestedImpl();
    }

    public V1ContainerStateFluent.TerminatedNested<A> withNewTerminatedLike(V1ContainerStateTerminated item){
            return new TerminatedNestedImpl(item);
    }

    public V1ContainerStateFluent.TerminatedNested<A> editTerminated(){
            return withNewTerminatedLike(getTerminated());
    }

    public V1ContainerStateFluent.TerminatedNested<A> editOrNewTerminated(){
            return withNewTerminatedLike(getTerminated() != null ? getTerminated(): new V1ContainerStateTerminatedBuilder().build());
    }

    public V1ContainerStateFluent.TerminatedNested<A> editOrNewTerminatedLike(V1ContainerStateTerminated item){
            return withNewTerminatedLike(getTerminated() != null ? getTerminated(): item);
    }

    
/**
 * This method has been deprecated, please use method buildWaiting instead.
 * @return The buildable object.
 */
@Deprecated public V1ContainerStateWaiting getWaiting(){
            return this.waiting!=null?this.waiting.build():null;
    }

    public V1ContainerStateWaiting buildWaiting(){
            return this.waiting!=null?this.waiting.build():null;
    }

    public A withWaiting(V1ContainerStateWaiting waiting){
            _visitables.remove(this.waiting);
            if (waiting!=null){ this.waiting= new V1ContainerStateWaitingBuilder(waiting); _visitables.add(this.waiting);} return (A) this;
    }

    public Boolean hasWaiting(){
            return this.waiting != null;
    }

    public V1ContainerStateFluent.WaitingNested<A> withNewWaiting(){
            return new WaitingNestedImpl();
    }

    public V1ContainerStateFluent.WaitingNested<A> withNewWaitingLike(V1ContainerStateWaiting item){
            return new WaitingNestedImpl(item);
    }

    public V1ContainerStateFluent.WaitingNested<A> editWaiting(){
            return withNewWaitingLike(getWaiting());
    }

    public V1ContainerStateFluent.WaitingNested<A> editOrNewWaiting(){
            return withNewWaitingLike(getWaiting() != null ? getWaiting(): new V1ContainerStateWaitingBuilder().build());
    }

    public V1ContainerStateFluent.WaitingNested<A> editOrNewWaitingLike(V1ContainerStateWaiting item){
            return withNewWaitingLike(getWaiting() != null ? getWaiting(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ContainerStateFluentImpl that = (V1ContainerStateFluentImpl) o;
            if (running != null ? !running.equals(that.running) :that.running != null) return false;
            if (terminated != null ? !terminated.equals(that.terminated) :that.terminated != null) return false;
            if (waiting != null ? !waiting.equals(that.waiting) :that.waiting != null) return false;
            return true;
    }


    public class RunningNestedImpl<N> extends V1ContainerStateRunningFluentImpl<V1ContainerStateFluent.RunningNested<N>> implements V1ContainerStateFluent.RunningNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ContainerStateRunningBuilder builder;
    
            RunningNestedImpl(V1ContainerStateRunning item){
                    this.builder = new V1ContainerStateRunningBuilder(this, item);
            }
            RunningNestedImpl(){
                    this.builder = new V1ContainerStateRunningBuilder(this);
            }
    
    public N and(){
            return (N) V1ContainerStateFluentImpl.this.withRunning(builder.build());
    }
    public N endRunning(){
            return and();
    }

}
    public class TerminatedNestedImpl<N> extends V1ContainerStateTerminatedFluentImpl<V1ContainerStateFluent.TerminatedNested<N>> implements V1ContainerStateFluent.TerminatedNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ContainerStateTerminatedBuilder builder;
    
            TerminatedNestedImpl(V1ContainerStateTerminated item){
                    this.builder = new V1ContainerStateTerminatedBuilder(this, item);
            }
            TerminatedNestedImpl(){
                    this.builder = new V1ContainerStateTerminatedBuilder(this);
            }
    
    public N and(){
            return (N) V1ContainerStateFluentImpl.this.withTerminated(builder.build());
    }
    public N endTerminated(){
            return and();
    }

}
    public class WaitingNestedImpl<N> extends V1ContainerStateWaitingFluentImpl<V1ContainerStateFluent.WaitingNested<N>> implements V1ContainerStateFluent.WaitingNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ContainerStateWaitingBuilder builder;
    
            WaitingNestedImpl(V1ContainerStateWaiting item){
                    this.builder = new V1ContainerStateWaitingBuilder(this, item);
            }
            WaitingNestedImpl(){
                    this.builder = new V1ContainerStateWaitingBuilder(this);
            }
    
    public N and(){
            return (N) V1ContainerStateFluentImpl.this.withWaiting(builder.build());
    }
    public N endWaiting(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1ContainerStateFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V1ContainerStateFluentImpl<A extends V1ContainerStateFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1ContainerStateFluent<A>{

    private V1ContainerStateRunningBuilder running;
    private V1ContainerStateTerminatedBuilder terminated;
    private V1ContainerStateWaitingBuilder waiting;

    public V1ContainerStateFluentImpl(){
    }
    public V1ContainerStateFluentImpl(V1ContainerState instance){
            this.withRunning(instance.getRunning());

            this.withTerminated(instance.getTerminated());

            this.withWaiting(instance.getWaiting());

    }

    
/**
 * This method has been deprecated, please use method buildRunning instead.
 * @return The buildable object.
 */
@Deprecated public V1ContainerStateRunning getRunning(){
            return this.running!=null?this.running.build():null;
    }

    public V1ContainerStateRunning buildRunning(){
            return this.running!=null?this.running.build():null;
    }

    public A withRunning(V1ContainerStateRunning running){
            _visitables.get("running").remove(this.running);
            if (running!=null){ this.running= new V1ContainerStateRunningBuilder(running); _visitables.get("running").add(this.running);} return (A) this;
    }

    public Boolean hasRunning(){
            return this.running != null;
    }

    public V1ContainerStateFluent.RunningNested<A> withNewRunning(){
            return new RunningNestedImpl();
    }

    public V1ContainerStateFluent.RunningNested<A> withNewRunningLike(V1ContainerStateRunning item){
            return new RunningNestedImpl(item);
    }

    public V1ContainerStateFluent.RunningNested<A> editRunning(){
            return withNewRunningLike(getRunning());
    }

    public V1ContainerStateFluent.RunningNested<A> editOrNewRunning(){
            return withNewRunningLike(getRunning() != null ? getRunning(): new V1ContainerStateRunningBuilder().build());
    }

    public V1ContainerStateFluent.RunningNested<A> editOrNewRunningLike(V1ContainerStateRunning item){
            return withNewRunningLike(getRunning() != null ? getRunning(): item);
    }

    
/**
 * This method has been deprecated, please use method buildTerminated instead.
 * @return The buildable object.
 */
@Deprecated public V1ContainerStateTerminated getTerminated(){
            return this.terminated!=null?this.terminated.build():null;
    }

    public V1ContainerStateTerminated buildTerminated(){
            return this.terminated!=null?this.terminated.build():null;
    }

    public A withTerminated(V1ContainerStateTerminated terminated){
            _visitables.get("terminated").remove(this.terminated);
            if (terminated!=null){ this.terminated= new V1ContainerStateTerminatedBuilder(terminated); _visitables.get("terminated").add(this.terminated);} return (A) this;
    }

    public Boolean hasTerminated(){
            return this.terminated != null;
    }

    public V1ContainerStateFluent.TerminatedNested<A> withNewTerminated(){
            return new TerminatedNestedImpl();
    }

    public V1ContainerStateFluent.TerminatedNested<A> withNewTerminatedLike(V1ContainerStateTerminated item){
            return new TerminatedNestedImpl(item);
    }

    public V1ContainerStateFluent.TerminatedNested<A> editTerminated(){
            return withNewTerminatedLike(getTerminated());
    }

    public V1ContainerStateFluent.TerminatedNested<A> editOrNewTerminated(){
            return withNewTerminatedLike(getTerminated() != null ? getTerminated(): new V1ContainerStateTerminatedBuilder().build());
    }

    public V1ContainerStateFluent.TerminatedNested<A> editOrNewTerminatedLike(V1ContainerStateTerminated item){
            return withNewTerminatedLike(getTerminated() != null ? getTerminated(): item);
    }

    
/**
 * This method has been deprecated, please use method buildWaiting instead.
 * @return The buildable object.
 */
@Deprecated public V1ContainerStateWaiting getWaiting(){
            return this.waiting!=null?this.waiting.build():null;
    }

    public V1ContainerStateWaiting buildWaiting(){
            return this.waiting!=null?this.waiting.build():null;
    }

    public A withWaiting(V1ContainerStateWaiting waiting){
            _visitables.get("waiting").remove(this.waiting);
            if (waiting!=null){ this.waiting= new V1ContainerStateWaitingBuilder(waiting); _visitables.get("waiting").add(this.waiting);} return (A) this;
    }

    public Boolean hasWaiting(){
            return this.waiting != null;
    }

    public V1ContainerStateFluent.WaitingNested<A> withNewWaiting(){
            return new WaitingNestedImpl();
    }

    public V1ContainerStateFluent.WaitingNested<A> withNewWaitingLike(V1ContainerStateWaiting item){
            return new WaitingNestedImpl(item);
    }

    public V1ContainerStateFluent.WaitingNested<A> editWaiting(){
            return withNewWaitingLike(getWaiting());
    }

    public V1ContainerStateFluent.WaitingNested<A> editOrNewWaiting(){
            return withNewWaitingLike(getWaiting() != null ? getWaiting(): new V1ContainerStateWaitingBuilder().build());
    }

    public V1ContainerStateFluent.WaitingNested<A> editOrNewWaitingLike(V1ContainerStateWaiting item){
            return withNewWaitingLike(getWaiting() != null ? getWaiting(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1ContainerStateFluentImpl that = (V1ContainerStateFluentImpl) o;
            if (running != null ? !running.equals(that.running) :that.running != null) return false;
            if (terminated != null ? !terminated.equals(that.terminated) :that.terminated != null) return false;
            if (waiting != null ? !waiting.equals(that.waiting) :that.waiting != null) return false;
            return true;
    }


    public class RunningNestedImpl<N> extends V1ContainerStateRunningFluentImpl<V1ContainerStateFluent.RunningNested<N>> implements V1ContainerStateFluent.RunningNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ContainerStateRunningBuilder builder;
    
            RunningNestedImpl(V1ContainerStateRunning item){
                    this.builder = new V1ContainerStateRunningBuilder(this, item);
            }
            RunningNestedImpl(){
                    this.builder = new V1ContainerStateRunningBuilder(this);
            }
    
    public N and(){
            return (N) V1ContainerStateFluentImpl.this.withRunning(builder.build());
    }
    public N endRunning(){
            return and();
    }

}
    public class TerminatedNestedImpl<N> extends V1ContainerStateTerminatedFluentImpl<V1ContainerStateFluent.TerminatedNested<N>> implements V1ContainerStateFluent.TerminatedNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ContainerStateTerminatedBuilder builder;
    
            TerminatedNestedImpl(V1ContainerStateTerminated item){
                    this.builder = new V1ContainerStateTerminatedBuilder(this, item);
            }
            TerminatedNestedImpl(){
                    this.builder = new V1ContainerStateTerminatedBuilder(this);
            }
    
    public N and(){
            return (N) V1ContainerStateFluentImpl.this.withTerminated(builder.build());
    }
    public N endTerminated(){
            return and();
    }

}
    public class WaitingNestedImpl<N> extends V1ContainerStateWaitingFluentImpl<V1ContainerStateFluent.WaitingNested<N>> implements V1ContainerStateFluent.WaitingNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V1ContainerStateWaitingBuilder builder;
    
            WaitingNestedImpl(V1ContainerStateWaiting item){
                    this.builder = new V1ContainerStateWaitingBuilder(this, item);
            }
            WaitingNestedImpl(){
                    this.builder = new V1ContainerStateWaitingBuilder(this);
            }
    
    public N and(){
            return (N) V1ContainerStateFluentImpl.this.withWaiting(builder.build());
    }
    public N endWaiting(){
            return and();
    }

}


}
